/* gnome-usage.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from gnome-usage.vala, do not modify */

/* gnome-usage.vala
 *
 * Copyright (C) 2017 Red Hat, Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Petr Štětka <pstetka@redhat.com>
 */

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <locale.h>
#include <adwaita.h>
#include <glib-object.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define USAGE_TYPE_APPLICATION (usage_application_get_type ())
#define USAGE_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), USAGE_TYPE_APPLICATION, UsageApplication))
#define USAGE_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), USAGE_TYPE_APPLICATION, UsageApplicationClass))
#define USAGE_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), USAGE_TYPE_APPLICATION))
#define USAGE_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), USAGE_TYPE_APPLICATION))
#define USAGE_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), USAGE_TYPE_APPLICATION, UsageApplicationClass))

typedef struct _UsageApplication UsageApplication;
typedef struct _UsageApplicationClass UsageApplicationClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

static gint _vala_main (gchar** args,
                 gint args_length1);
VALA_EXTERN GType usage_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UsageApplication, g_object_unref)
VALA_EXTERN UsageApplication* usage_application_new (void);
VALA_EXTERN UsageApplication* usage_application_construct (GType object_type);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static gint
_vala_main (gchar** args,
            gint args_length1)
{
	UsageApplication* application = NULL;
	UsageApplication* _tmp0_;
	gint result;
	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
	setlocale (LC_ALL, "");
	textdomain (GETTEXT_PACKAGE);
	bind_textdomain_codeset (GETTEXT_PACKAGE, "utf-8");
	_tmp0_ = usage_application_new ();
	application = _tmp0_;
	result = g_application_run ((GApplication*) application, (gint) args_length1, args);
	_g_object_unref0 (application);
	return result;
}

int
main (int argc,
      char ** argv)
{
	return _vala_main (argv, argc);
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

