/* no-results-found-view.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from no-results-found-view.vala, do not modify */

/* no-results-found-box.vala
 *
 * Copyright (C) 2017 Radhika Dua <radhikadua1997@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define USAGE_TYPE_NO_RESULTS_FOUND_VIEW (usage_no_results_found_view_get_type ())
#define USAGE_NO_RESULTS_FOUND_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), USAGE_TYPE_NO_RESULTS_FOUND_VIEW, UsageNoResultsFoundView))
#define USAGE_NO_RESULTS_FOUND_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), USAGE_TYPE_NO_RESULTS_FOUND_VIEW, UsageNoResultsFoundViewClass))
#define USAGE_IS_NO_RESULTS_FOUND_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), USAGE_TYPE_NO_RESULTS_FOUND_VIEW))
#define USAGE_IS_NO_RESULTS_FOUND_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), USAGE_TYPE_NO_RESULTS_FOUND_VIEW))
#define USAGE_NO_RESULTS_FOUND_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), USAGE_TYPE_NO_RESULTS_FOUND_VIEW, UsageNoResultsFoundViewClass))

typedef struct _UsageNoResultsFoundView UsageNoResultsFoundView;
typedef struct _UsageNoResultsFoundViewClass UsageNoResultsFoundViewClass;
typedef struct _UsageNoResultsFoundViewPrivate UsageNoResultsFoundViewPrivate;
enum  {
	USAGE_NO_RESULTS_FOUND_VIEW_0_PROPERTY,
	USAGE_NO_RESULTS_FOUND_VIEW_NUM_PROPERTIES
};
static GParamSpec* usage_no_results_found_view_properties[USAGE_NO_RESULTS_FOUND_VIEW_NUM_PROPERTIES];

struct _UsageNoResultsFoundView {
	AdwBin parent_instance;
	UsageNoResultsFoundViewPrivate * priv;
};

struct _UsageNoResultsFoundViewClass {
	AdwBinClass parent_class;
};

static gpointer usage_no_results_found_view_parent_class = NULL;

VALA_EXTERN GType usage_no_results_found_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UsageNoResultsFoundView, g_object_unref)
VALA_EXTERN UsageNoResultsFoundView* usage_no_results_found_view_new (void);
VALA_EXTERN UsageNoResultsFoundView* usage_no_results_found_view_construct (GType object_type);
static GType usage_no_results_found_view_get_type_once (void);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

UsageNoResultsFoundView*
usage_no_results_found_view_construct (GType object_type)
{
	UsageNoResultsFoundView * self = NULL;
	self = (UsageNoResultsFoundView*) g_object_new (object_type, NULL);
	return self;
}

UsageNoResultsFoundView*
usage_no_results_found_view_new (void)
{
	return usage_no_results_found_view_construct (USAGE_TYPE_NO_RESULTS_FOUND_VIEW);
}

static void
usage_no_results_found_view_class_init (UsageNoResultsFoundViewClass * klass,
                                        gpointer klass_data)
{
	usage_no_results_found_view_parent_class = g_type_class_peek_parent (klass);
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Usage/ui/no-results-found-view.ui");
}

static void
usage_no_results_found_view_instance_init (UsageNoResultsFoundView * self,
                                           gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

static GType
usage_no_results_found_view_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (UsageNoResultsFoundViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) usage_no_results_found_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (UsageNoResultsFoundView), 0, (GInstanceInitFunc) usage_no_results_found_view_instance_init, NULL };
	GType usage_no_results_found_view_type_id;
	usage_no_results_found_view_type_id = g_type_register_static (adw_bin_get_type (), "UsageNoResultsFoundView", &g_define_type_info, 0);
	return usage_no_results_found_view_type_id;
}

GType
usage_no_results_found_view_get_type (void)
{
	static volatile gsize usage_no_results_found_view_type_id__once = 0;
	if (g_once_init_enter (&usage_no_results_found_view_type_id__once)) {
		GType usage_no_results_found_view_type_id;
		usage_no_results_found_view_type_id = usage_no_results_found_view_get_type_once ();
		g_once_init_leave (&usage_no_results_found_view_type_id__once, usage_no_results_found_view_type_id);
	}
	return usage_no_results_found_view_type_id__once;
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

