/* query-builder.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from query-builder.vala, do not modify */

/* query-builder.vala
 *
 * Copyright (C) 2018 Red Hat, Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Felipe Borges <felipeborges@gnome.org>
 */

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define USAGE_TYPE_STORAGE_QUERY_BUILDER (usage_storage_query_builder_get_type ())
#define USAGE_STORAGE_QUERY_BUILDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), USAGE_TYPE_STORAGE_QUERY_BUILDER, UsageStorageQueryBuilder))
#define USAGE_STORAGE_QUERY_BUILDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), USAGE_TYPE_STORAGE_QUERY_BUILDER, UsageStorageQueryBuilderClass))
#define USAGE_IS_STORAGE_QUERY_BUILDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), USAGE_TYPE_STORAGE_QUERY_BUILDER))
#define USAGE_IS_STORAGE_QUERY_BUILDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), USAGE_TYPE_STORAGE_QUERY_BUILDER))
#define USAGE_STORAGE_QUERY_BUILDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), USAGE_TYPE_STORAGE_QUERY_BUILDER, UsageStorageQueryBuilderClass))

typedef struct _UsageStorageQueryBuilder UsageStorageQueryBuilder;
typedef struct _UsageStorageQueryBuilderClass UsageStorageQueryBuilderClass;
typedef struct _UsageStorageQueryBuilderPrivate UsageStorageQueryBuilderPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _UsageParamSpecStorageQueryBuilder UsageParamSpecStorageQueryBuilder;

struct _UsageStorageQueryBuilder {
	GTypeInstance parent_instance;
	volatile int ref_count;
	UsageStorageQueryBuilderPrivate * priv;
};

struct _UsageStorageQueryBuilderClass {
	GTypeClass parent_class;
	void (*finalize) (UsageStorageQueryBuilder *self);
};

struct _UsageParamSpecStorageQueryBuilder {
	GParamSpec parent_instance;
};

static gpointer usage_storage_query_builder_parent_class = NULL;

VALA_EXTERN gpointer usage_storage_query_builder_ref (gpointer instance);
VALA_EXTERN void usage_storage_query_builder_unref (gpointer instance);
VALA_EXTERN GParamSpec* usage_param_spec_storage_query_builder (const gchar* name,
                                                    const gchar* nick,
                                                    const gchar* blurb,
                                                    GType object_type,
                                                    GParamFlags flags);
VALA_EXTERN void usage_value_set_storage_query_builder (GValue* value,
                                            gpointer v_object);
VALA_EXTERN void usage_value_take_storage_query_builder (GValue* value,
                                             gpointer v_object);
VALA_EXTERN gpointer usage_value_get_storage_query_builder (const GValue* value);
VALA_EXTERN GType usage_storage_query_builder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UsageStorageQueryBuilder, usage_storage_query_builder_unref)
VALA_EXTERN gchar* usage_storage_query_builder_enumerate_children (UsageStorageQueryBuilder* self,
                                                       const gchar* uri,
                                                       gboolean recursive);
VALA_EXTERN UsageStorageQueryBuilder* usage_storage_query_builder_new (void);
VALA_EXTERN UsageStorageQueryBuilder* usage_storage_query_builder_construct (GType object_type);
static void usage_storage_query_builder_finalize (UsageStorageQueryBuilder * obj);
static GType usage_storage_query_builder_get_type_once (void);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

gchar*
usage_storage_query_builder_enumerate_children (UsageStorageQueryBuilder* self,
                                                const gchar* uri,
                                                gboolean recursive)
{
	gchar* filter = NULL;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (uri != NULL, NULL);
	if (recursive) {
		const gchar* _tmp0_;
		gchar* _tmp1_;
		_tmp0_ = string_to_string (uri);
		_tmp1_ = g_strconcat ("tracker:uri-is-descendant ('", _tmp0_, "', ?uri)", NULL);
		_g_free0 (filter);
		filter = _tmp1_;
	} else {
		const gchar* _tmp2_;
		gchar* _tmp3_;
		_tmp2_ = string_to_string (uri);
		_tmp3_ = g_strconcat ("tracker:uri-is-parent ('", _tmp2_, "', ?uri)", NULL);
		_g_free0 (filter);
		filter = _tmp3_;
	}
	_tmp4_ = filter;
	_tmp5_ = string_to_string (_tmp4_);
	_tmp6_ = g_strconcat ("SELECT ?uri rdf:type(?u) FROM tracker:FileSystem { ?u nie:url ?uri . F" \
"ILTER(", _tmp5_, ") }", NULL);
	result = _tmp6_;
	_g_free0 (filter);
	return result;
}

UsageStorageQueryBuilder*
usage_storage_query_builder_construct (GType object_type)
{
	UsageStorageQueryBuilder* self = NULL;
	self = (UsageStorageQueryBuilder*) g_type_create_instance (object_type);
	return self;
}

UsageStorageQueryBuilder*
usage_storage_query_builder_new (void)
{
	return usage_storage_query_builder_construct (USAGE_TYPE_STORAGE_QUERY_BUILDER);
}

static void
usage_value_storage_query_builder_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
usage_value_storage_query_builder_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		usage_storage_query_builder_unref (value->data[0].v_pointer);
	}
}

static void
usage_value_storage_query_builder_copy_value (const GValue* src_value,
                                              GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = usage_storage_query_builder_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
usage_value_storage_query_builder_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
usage_value_storage_query_builder_collect_value (GValue* value,
                                                 guint n_collect_values,
                                                 GTypeCValue* collect_values,
                                                 guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		UsageStorageQueryBuilder * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = usage_storage_query_builder_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
usage_value_storage_query_builder_lcopy_value (const GValue* value,
                                               guint n_collect_values,
                                               GTypeCValue* collect_values,
                                               guint collect_flags)
{
	UsageStorageQueryBuilder ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = usage_storage_query_builder_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
usage_param_spec_storage_query_builder (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags)
{
	UsageParamSpecStorageQueryBuilder* spec;
	g_return_val_if_fail (g_type_is_a (object_type, USAGE_TYPE_STORAGE_QUERY_BUILDER), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
usage_value_get_storage_query_builder (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, USAGE_TYPE_STORAGE_QUERY_BUILDER), NULL);
	return value->data[0].v_pointer;
}

void
usage_value_set_storage_query_builder (GValue* value,
                                       gpointer v_object)
{
	UsageStorageQueryBuilder * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, USAGE_TYPE_STORAGE_QUERY_BUILDER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, USAGE_TYPE_STORAGE_QUERY_BUILDER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		usage_storage_query_builder_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		usage_storage_query_builder_unref (old);
	}
}

void
usage_value_take_storage_query_builder (GValue* value,
                                        gpointer v_object)
{
	UsageStorageQueryBuilder * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, USAGE_TYPE_STORAGE_QUERY_BUILDER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, USAGE_TYPE_STORAGE_QUERY_BUILDER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		usage_storage_query_builder_unref (old);
	}
}

static void
usage_storage_query_builder_class_init (UsageStorageQueryBuilderClass * klass,
                                        gpointer klass_data)
{
	usage_storage_query_builder_parent_class = g_type_class_peek_parent (klass);
	((UsageStorageQueryBuilderClass *) klass)->finalize = usage_storage_query_builder_finalize;
}

static void
usage_storage_query_builder_instance_init (UsageStorageQueryBuilder * self,
                                           gpointer klass)
{
	self->ref_count = 1;
}

static void
usage_storage_query_builder_finalize (UsageStorageQueryBuilder * obj)
{
	UsageStorageQueryBuilder * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, USAGE_TYPE_STORAGE_QUERY_BUILDER, UsageStorageQueryBuilder);
	g_signal_handlers_destroy (self);
}

static GType
usage_storage_query_builder_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { usage_value_storage_query_builder_init, usage_value_storage_query_builder_free_value, usage_value_storage_query_builder_copy_value, usage_value_storage_query_builder_peek_pointer, "p", usage_value_storage_query_builder_collect_value, "p", usage_value_storage_query_builder_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (UsageStorageQueryBuilderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) usage_storage_query_builder_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (UsageStorageQueryBuilder), 0, (GInstanceInitFunc) usage_storage_query_builder_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType usage_storage_query_builder_type_id;
	usage_storage_query_builder_type_id = g_type_register_fundamental (g_type_fundamental_next (), "UsageStorageQueryBuilder", &g_define_type_info, &g_define_type_fundamental_info, 0);
	return usage_storage_query_builder_type_id;
}

GType
usage_storage_query_builder_get_type (void)
{
	static volatile gsize usage_storage_query_builder_type_id__once = 0;
	if (g_once_init_enter (&usage_storage_query_builder_type_id__once)) {
		GType usage_storage_query_builder_type_id;
		usage_storage_query_builder_type_id = usage_storage_query_builder_get_type_once ();
		g_once_init_leave (&usage_storage_query_builder_type_id__once, usage_storage_query_builder_type_id);
	}
	return usage_storage_query_builder_type_id__once;
}

gpointer
usage_storage_query_builder_ref (gpointer instance)
{
	UsageStorageQueryBuilder * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
usage_storage_query_builder_unref (gpointer instance)
{
	UsageStorageQueryBuilder * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		USAGE_STORAGE_QUERY_BUILDER_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

